@@ -19,7 +19,16 @@ lookup_seq_fun <- function(x) {
 }
 
 lookup_seq_fun.POSIXct <- function(x) {
-  seq.POSIXt
+
+  # For POSIXct object, DST can cause problems with
+  # rollover between DST boundaries. See #31. Using DSTday as the "by"
+  # uses the actual "clock time" which is what is commonly desired.
+  function(from, to, by) {
+    if(grepl(pattern = "day", by)) {
+      by <- gsub("day", "DSTday", by)
+    }
+    seq.POSIXt(from, to, by)
+  }
 }
 
 lookup_seq_fun.Date <- function(x) {
@@ -55,8 +64,8 @@ push_datetime.default <- function(x, push) {
 
   posixct_numeric_to_datetime(
     pushed,
-    class = get_index_col_class(x_num),
-    tz = get_index_col_time_zone(x_num)
+    class = get_index_col_class(x),
+    tz = get_index_col_time_zone(x)
   )
 }
 
@@ -134,7 +143,7 @@ split_to_list.Date <- function(x) {
 
 #' @export
 split_to_list.POSIXct <- function(x) {
-  x_lt <- as.POSIXlt(x, tz = attr(x, "tzone"))
+  x_lt <- as.POSIXlt(x, tz = get_index_col_time_zone(x))
   list(x_lt$year + 1900, x_lt$mon + 1, x_lt$mday,
        x_lt$hour,        x_lt$min, x_lt$sec)
 }
